@@ -334,7 +334,7 @@ class argLaTeXBackend(argBackendBase):
                     f_out.write(l)
 
     @staticmethod
-    def generate_text(text):
+    def generate_text(text, type="default"):
         """Add page break to the report
         """
 
